API
===

Page Objects
-------------
.. automodule:: holmium.core 
    :members:

.. autoclass:: PageObject
.. autoclass:: PageElement
.. autoclass:: PageElements 
.. autoclass:: PageElementMap
.. autoclass:: Locators
    :undoc-members:
    :inherited-members:

Utilities
---------
.. autoclass:: HolmiumTestCase
.. autofunction:: repeat 
